from django.db import models


class BrowsConf(models.Model):
    """ stores config-info used for browsing views """
    model_name = models.CharField(
        max_length=255, blank=True,
        help_text="The name of the model class you like to analyse."
    )
    label = models.CharField(
        max_length=255, blank=True, help_text="The label of the value of interest."
    )
    field_path = models.CharField(
        max_length=255, blank=True, help_text="The constructor of to the value of interest."
    )

    def __str__(self):
        return "{}.{} ({})".format(self.model_name, self.field_path, self.label)



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


setup(
    name='acdh-django-browsing',
    version='0.0.1',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description='Django-App providing some useful things to create browsing views',
    long_description=README,
    url='https://github.com/acdh-oeaw/acdh-django-browsing',
    author='Peter Andorfer',
    author_email='peter.andorfer@oeaw.ac.at',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',  # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
    ],
    install_requires=[
        'Django>=3.0',
        'django-autocomplete-light>=3.3.5',
        'django-crispy-forms>=1.7.2',
        'django-filter>=2.1.0',
        'django-super-deduper>=0.1.2',
        'django-tables2>=2.0.6',
    ],
)
